.. _changelog:

=========
CHANGELOG
=========


.. _changelog-v0.0.6:

v0.0.6 (2025-07-21)
===================

Bug Fixes
---------

* fix: add RNG logging and verbosity (`e2cb737`_)

Unknown
-------

* Merge branch 'main' of github.com:nz-gravity/LogPSplinePSD (`a69cd29`_)

.. _e2cb737: https://github.com/nz-gravity/LogPSplinePSD/commit/e2cb7372ba51127727d7598f6c1dcad7bf038449
.. _a69cd29: https://github.com/nz-gravity/LogPSplinePSD/commit/a69cd29df0326f764176b1ef586a270b7f6b7d2c


.. _changelog-v0.0.5:

v0.0.5 (2025-07-21)
===================

Bug Fixes
---------

* fix: update runner (`85edc41`_)

* fix: add benchmarking fix for cli (`8914c67`_)

Chores
------

* chore(release): 0.0.5 (`f3cfd37`_)

Unknown
-------

* add benchmarking code (`1361278`_)

* add ESS comparison (`88b8792`_)

.. _85edc41: https://github.com/nz-gravity/LogPSplinePSD/commit/85edc41f866cfc9200c7267cceaae2a0c681fd82
.. _8914c67: https://github.com/nz-gravity/LogPSplinePSD/commit/8914c6733dbcecd1543cde23f20553ced1a6fbba
.. _f3cfd37: https://github.com/nz-gravity/LogPSplinePSD/commit/f3cfd3750f940f1c12740aa5fe82c7c05384df21
.. _1361278: https://github.com/nz-gravity/LogPSplinePSD/commit/1361278de8c80c9e2509480325f7f160bf833259
.. _88b8792: https://github.com/nz-gravity/LogPSplinePSD/commit/88b879285577f13e53c844f19f18c26cb8cd4cb5


.. _changelog-v0.0.4:

v0.0.4 (2025-07-17)
===================

Bug Fixes
---------

* fix: update inference result saving/loading (`c1c6273`_)

Chores
------

* chore(release): 0.0.4 (`b4016a2`_)

Unknown
-------

* Merge branch 'main' of github.com:nz-gravity/LogPSplinePSD (`49e3a72`_)

.. _c1c6273: https://github.com/nz-gravity/LogPSplinePSD/commit/c1c627301a886a792c25b60fa85dee13d173eceb
.. _b4016a2: https://github.com/nz-gravity/LogPSplinePSD/commit/b4016a25e0e8ae3fa6d614cc442d36e53bfe335c
.. _49e3a72: https://github.com/nz-gravity/LogPSplinePSD/commit/49e3a727d479206fa16eeba3b8828acb48141356


.. _changelog-v0.0.3:

v0.0.3 (2025-07-16)
===================

Chores
------

* chore(release): 0.0.3 (`4ef53a9`_)

Unknown
-------

* update readme links (`0385b74`_)

* Merge branch 'main' of github.com:nz-gravity/LogPSplinePSD (`4c72cc2`_)

.. _4ef53a9: https://github.com/nz-gravity/LogPSplinePSD/commit/4ef53a986e41573a8b159416f0ce127aeb202872
.. _0385b74: https://github.com/nz-gravity/LogPSplinePSD/commit/0385b745795411e7e42790da58269c43ff5611d5
.. _4c72cc2: https://github.com/nz-gravity/LogPSplinePSD/commit/4c72cc2028d58dceeb717915f6bf2d9fb194a9c2


.. _changelog-v0.0.2:

v0.0.2 (2025-07-16)
===================

Bug Fixes
---------

* fix: fix pypi name bug (`b4b06db`_)

* fix: pypi readme fix and updating demo (`7ecc602`_)

Chores
------

* chore(release): 0.0.2 (`1d35bb9`_)

Unknown
-------

* Merge branch 'main' of github.com:nz-gravity/LogPSplinePSD (`5121194`_)

.. _b4b06db: https://github.com/nz-gravity/LogPSplinePSD/commit/b4b06db36c36e72793d659e317ce26af52108865
.. _7ecc602: https://github.com/nz-gravity/LogPSplinePSD/commit/7ecc602bc7c066bcd9b86be4340575d10057c01c
.. _1d35bb9: https://github.com/nz-gravity/LogPSplinePSD/commit/1d35bb982f74f1ae9be5021a983f4267b0627cfc
.. _5121194: https://github.com/nz-gravity/LogPSplinePSD/commit/5121194a38c18dfbf31e7bcc9c3751409d4cb9b7


.. _changelog-v0.0.1:

v0.0.1 (2025-07-16)
===================

Bug Fixes
---------

* fix: add gwpy for dev options (`964e40e`_)

* fix: add arviz (`7a0925c`_)

* fix: add diagostics and ar dataset for tstig (`a43ee40`_)

* fix: add demo to docs (`235c3ec`_)

* fix: init weights with mse istead of lnl (`9df1e5d`_)

Chores
------

* chore(release): 0.0.1 (`027591f`_)

Unknown
-------

* Update pypi.yml (`88c8f9b`_)

* edit readme (`60af98d`_)

* add: add option for mh and nuts (`3a08b99`_)

* refactoring to use a common parent class (`1fb79e8`_)

* change to just vanilla metropolis-hastings (get rid of covar matrix adaptation) (`b0cd698`_)

* Merge pull request #3 from nz-gravity/adding_adaptive_mcmc

Adding adaptive MCMC (`fd9a95b`_)

* init (`c41038c`_)

* fix tests (`328e854`_)

* Update docs.yml (`5877ec0`_)

* Update README.rst (`20d3f39`_)

* add line locator (`dc6469c`_)

* add fix (`7f32bbb`_)

* refactor (`a061028`_)

* add docs (`6b3905f`_)

* add examples (`cf42e6f`_)

* add psd approx (`18d0075`_)

* Merge branch 'main' of github.com:avivajpeyi/LogPSplinePSD (`a2035bb`_)

* Create LICENSE (`8fff25b`_)

* fix readme (`939cbdb`_)

* add workflows (`73fd427`_)

* Merge branch 'main' of github.com:avivajpeyi/LogPSplinePSD (`194fae8`_)

* Merge pull request #1 from avivajpeyi/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate (`7231c3b`_)

* [pre-commit.ci] auto fixes from pre-commit.com hooks

for more information, see https://pre-commit.ci (`6641a63`_)

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/pre-commit/pre-commit-hooks: v4.5.0 → v5.0.0](https://github.com/pre-commit/pre-commit-hooks/compare/v4.5.0...v5.0.0)
- https://github.com/pre-commit/mirrors-isort → https://github.com/PyCQA/isort
- [github.com/PyCQA/isort: v5.10.1 → 6.0.1](https://github.com/PyCQA/isort/compare/v5.10.1...6.0.1)
- https://github.com/ambv/black → https://github.com/psf/black
- [github.com/psf/black: 23.10.0 → 25.1.0](https://github.com/psf/black/compare/23.10.0...25.1.0)
- [github.com/psf/black: 23.10.0 → 25.1.0](https://github.com/psf/black/compare/23.10.0...25.1.0) (`98ae77a`_)

* add welch psd (`d7121d6`_)

* add LVK plots (`f818caa`_)

* add LVK example and parametric model (`0666415`_)

* hackig on alternative model (`4197563`_)

* add LVK example (`922f870`_)

* add LVK example (`4944aa1`_)

* add lvk noise (`d93f36b`_)

* add tests (`c9e3c79`_)

* more hacking (`fda820d`_)

* add ci (`3539ffb`_)

* add whitepsace (`3274b74`_)

* hacking with Benjamin (`23210a3`_)

* init project packaging (`5685aac`_)

* improve knot allocation (`8e4ad33`_)

* optimise starting weights (`1942d60`_)

* generate data for testing (`0d619ce`_)

* start hacking (`cd4026f`_)

.. _964e40e: https://github.com/nz-gravity/LogPSplinePSD/commit/964e40e8191ad20bdf3028bb268196312983058d
.. _7a0925c: https://github.com/nz-gravity/LogPSplinePSD/commit/7a0925cf8158fe5122ce68b9a41b9534af638099
.. _a43ee40: https://github.com/nz-gravity/LogPSplinePSD/commit/a43ee406b85b00fe480c36f9fbe1b45ce70a0683
.. _235c3ec: https://github.com/nz-gravity/LogPSplinePSD/commit/235c3ec5191c5c71952a820697d4416fc9b319e5
.. _9df1e5d: https://github.com/nz-gravity/LogPSplinePSD/commit/9df1e5d7527d08602a4402cb038e88c8aa474128
.. _027591f: https://github.com/nz-gravity/LogPSplinePSD/commit/027591fd3b4ecd334d784f25395d7bd5353c9ab2
.. _88c8f9b: https://github.com/nz-gravity/LogPSplinePSD/commit/88c8f9bc873be650cbcac1a2a3440db803b0afe5
.. _60af98d: https://github.com/nz-gravity/LogPSplinePSD/commit/60af98d50e3370107a7373018d72041a7f67e11d
.. _3a08b99: https://github.com/nz-gravity/LogPSplinePSD/commit/3a08b992d695f4bd9c9c8130989ee3de51341fed
.. _1fb79e8: https://github.com/nz-gravity/LogPSplinePSD/commit/1fb79e8689f87f89a4363d264bb1e33fbaf9217c
.. _b0cd698: https://github.com/nz-gravity/LogPSplinePSD/commit/b0cd6985070d56f217c4f63c6bc4f8da66c565ec
.. _fd9a95b: https://github.com/nz-gravity/LogPSplinePSD/commit/fd9a95bc154a1b7d009b3c4cb680a3cee9abfa5d
.. _c41038c: https://github.com/nz-gravity/LogPSplinePSD/commit/c41038cdc5ae858db11022f599862bf3becf4a69
.. _328e854: https://github.com/nz-gravity/LogPSplinePSD/commit/328e854df63dec4eacc4ec2738021c6c183489fb
.. _5877ec0: https://github.com/nz-gravity/LogPSplinePSD/commit/5877ec0c672fe51ad7013ebcdc931e30df990356
.. _20d3f39: https://github.com/nz-gravity/LogPSplinePSD/commit/20d3f393a5446bb1cd32f1661edd7993fff8ba97
.. _dc6469c: https://github.com/nz-gravity/LogPSplinePSD/commit/dc6469cff708fb172d5e90f2871ee57fb8e6c43a
.. _7f32bbb: https://github.com/nz-gravity/LogPSplinePSD/commit/7f32bbba2ddd96a0db3667ad1312b8acf7855a3d
.. _a061028: https://github.com/nz-gravity/LogPSplinePSD/commit/a06102836f95960b1699a073adbf441ea195b75c
.. _6b3905f: https://github.com/nz-gravity/LogPSplinePSD/commit/6b3905f03298d737dc1b940f7b4756dcbe122998
.. _cf42e6f: https://github.com/nz-gravity/LogPSplinePSD/commit/cf42e6f83eece3202eb747f09b1af55887082abb
.. _18d0075: https://github.com/nz-gravity/LogPSplinePSD/commit/18d007562a3e31dbed39a8c3b199252f951d03f7
.. _a2035bb: https://github.com/nz-gravity/LogPSplinePSD/commit/a2035bb40da74aa11dfd740af7b98af0a9d33ba5
.. _8fff25b: https://github.com/nz-gravity/LogPSplinePSD/commit/8fff25b4ae70f2627ca45c37ed57af842dd13353
.. _939cbdb: https://github.com/nz-gravity/LogPSplinePSD/commit/939cbdb650fbfdf460666ebb6f7e465f799e6e6e
.. _73fd427: https://github.com/nz-gravity/LogPSplinePSD/commit/73fd4276b6f44d68cfbb7fb16797be891f7e114a
.. _194fae8: https://github.com/nz-gravity/LogPSplinePSD/commit/194fae8d527bd7998dda38adaf0b96002c070414
.. _7231c3b: https://github.com/nz-gravity/LogPSplinePSD/commit/7231c3b1de002ee47b10286c4f799ae3551d4c40
.. _6641a63: https://github.com/nz-gravity/LogPSplinePSD/commit/6641a63c97f0c5392207fd56977ee37cf9811ac6
.. _98ae77a: https://github.com/nz-gravity/LogPSplinePSD/commit/98ae77ad38feaca0d65566f26d42e3adafe9f772
.. _d7121d6: https://github.com/nz-gravity/LogPSplinePSD/commit/d7121d6c1cd87a65355b4a6f6260578b90223339
.. _f818caa: https://github.com/nz-gravity/LogPSplinePSD/commit/f818caaa86467d5f26fb116a2c29c7a360ff41cf
.. _0666415: https://github.com/nz-gravity/LogPSplinePSD/commit/0666415347785d67b2865efe521648a7a89ee000
.. _4197563: https://github.com/nz-gravity/LogPSplinePSD/commit/4197563ebdd5da00a781dc22556eeb925f1cceaf
.. _922f870: https://github.com/nz-gravity/LogPSplinePSD/commit/922f87003a657d1578a98c3d3d803055f7969fe2
.. _4944aa1: https://github.com/nz-gravity/LogPSplinePSD/commit/4944aa1501d382d8ee4f6e06780c672e588b843d
.. _d93f36b: https://github.com/nz-gravity/LogPSplinePSD/commit/d93f36bcba5a70f2d90b40c3934de265f72cb65f
.. _c9e3c79: https://github.com/nz-gravity/LogPSplinePSD/commit/c9e3c790dff28a51bf9dc97b56bd63ccbcddd43b
.. _fda820d: https://github.com/nz-gravity/LogPSplinePSD/commit/fda820dd58f3072c86876d2a2ae218869f656f6e
.. _3539ffb: https://github.com/nz-gravity/LogPSplinePSD/commit/3539ffb0b1d87445201633488da63743454e0c7f
.. _3274b74: https://github.com/nz-gravity/LogPSplinePSD/commit/3274b74c1f0c59ea43825bdca177f99f8c8fe097
.. _23210a3: https://github.com/nz-gravity/LogPSplinePSD/commit/23210a35eb751832563a69101817ba906b82edba
.. _5685aac: https://github.com/nz-gravity/LogPSplinePSD/commit/5685aac389781eaeeadda6a1c31f2820b61cbed1
.. _8e4ad33: https://github.com/nz-gravity/LogPSplinePSD/commit/8e4ad33d4e99f20a2a76d40dd8539838ed5462ea
.. _1942d60: https://github.com/nz-gravity/LogPSplinePSD/commit/1942d6079393eb78ddcc07a7a4265805bcfcb010
.. _0d619ce: https://github.com/nz-gravity/LogPSplinePSD/commit/0d619ceba76869e3ec3b2d015987a77a1671cf19
.. _cd4026f: https://github.com/nz-gravity/LogPSplinePSD/commit/cd4026f9c50b1384a4cfba70cf8e67f938a254ac
